summaryrefslogtreecommitdiff
path: root/libpanto/src/tool_source.zig
diff options
context:
space:
mode:
Diffstat (limited to 'libpanto/src/tool_source.zig')
-rw-r--r--libpanto/src/tool_source.zig8
1 files changed, 5 insertions, 3 deletions
diff --git a/libpanto/src/tool_source.zig b/libpanto/src/tool_source.zig
index bf1f5a1..d5bc716 100644
--- a/libpanto/src/tool_source.zig
+++ b/libpanto/src/tool_source.zig
@@ -36,6 +36,7 @@ const tool = @import("tool.zig");
/// single dispatch path.
pub const ToolDecl = tool.ToolDecl;
pub const ResultPart = tool.ResultPart;
+pub const ResultParts = tool.ResultParts;
/// One pending invocation passed to `invoke_batch`. Slices borrowed from
/// the caller for the duration of the call.
@@ -49,9 +50,10 @@ pub const Call = struct {
/// Result for a single call. Mirrors the success/error split of
/// `Tool.invoke`'s return shape. Owned by the caller-supplied allocator.
pub const CallResult = union(enum) {
- /// Owned parts (slice + each part's bytes), freed by libpanto after
- /// assembling the ToolResult block (see `tool.freeResultParts`).
- ok: []ResultPart,
+ /// Owned parts (the `ResultParts` slice + each part's bytes), freed by
+ /// libpanto after assembling the ToolResult block (see
+ /// `tool.ResultParts.deinit`).
+ ok: ResultParts,
err: anyerror,
};